import * as postcss_lib_no_work_result from 'postcss/lib/no-work-result';
import postcss from 'postcss';
import { ClassGenerator } from '@tailwindcss-mangle/shared';
export { ClassGenerator } from '@tailwindcss-mangle/shared';
import { StringLiteral, TemplateElement } from '@babel/types';
import { BabelFileResult } from '@babel/core';

interface IClassGeneratorContextItem {
    name: string;
    usedBy: string[];
}
interface IClassGeneratorOptions {
    reserveClassName?: (string | RegExp)[];
    customGenerate?: (original: string, opts: IClassGeneratorOptions, context: Record<string, any>) => string | undefined;
    log?: boolean;
    exclude?: (string | RegExp)[];
    include?: (string | RegExp)[];
    ignoreClass?: (string | RegExp)[];
    classPrefix?: string;
}
interface IHandlerOptions {
    classGenerator: ClassGenerator;
    replaceMap: Map<string, string>;
}
interface IHtmlHandlerOptions extends IHandlerOptions {
}
interface IJsHandlerOptions extends IHandlerOptions {
    splitQuote?: boolean;
    minified?: boolean;
}
interface ICssHandlerOptions extends IHandlerOptions {
    ignoreVueScoped?: boolean;
    file?: string;
}
interface ClassSetOutputOptions {
    filename: string;
    dir?: string;
    type: 'all' | 'partial';
}
interface ClassMapOutputOptions {
    filename: string;
    dir?: string;
}
interface Options {
    classGenerator?: IClassGeneratorOptions;
    exclude?: string[];
    include?: string[];
    classSetOutput?: boolean | ClassSetOutputOptions;
    classMapOutput?: boolean | ClassMapOutputOptions;
}

declare function cssHandler(rawSource: string, options: ICssHandlerOptions): postcss.LazyResult | postcss_lib_no_work_result.default;

declare function htmlHandler(rawSource: string, options: IHtmlHandlerOptions): string;

declare function preProcessJs(options: {
    code: string;
    replaceMap: Map<string, string>;
    id: string;
    addToUsedBy: (key: string, file: string) => void;
}): string;

declare function handleValue(raw: string, node: StringLiteral | TemplateElement, options: IJsHandlerOptions): string;
declare function jsHandler(rawSource: string, options: IJsHandlerOptions): BabelFileResult;

export { ClassMapOutputOptions, ClassSetOutputOptions, IClassGeneratorContextItem, IClassGeneratorOptions, ICssHandlerOptions, IHandlerOptions, IHtmlHandlerOptions, IJsHandlerOptions, Options, cssHandler, handleValue, htmlHandler, jsHandler, preProcessJs };
